""" Server-package

    Initialize app, cors, database and bcrypt (for passwordhashing) and added it to the application.
    Initialize also a singelton for the AccesTokenControler and start the Thread.

"""
from .logger import getLogger
from geruecht.controller import dbConfig
from flask_mysqldb import MySQL

LOGGER = getLogger(__name__)
LOGGER.info("Initialize App")

from flask import Flask
from flask_cors import CORS

LOGGER.info("Build APP")
app = Flask(__name__)
CORS(app)
app.config['SECRET_KEY'] = '0a657b97ef546da90b2db91862ad4e29'
app.config['MYSQL_HOST'] = dbConfig['URL']
app.config['MYSQL_USER'] = dbConfig['user']
app.config['MYSQL_PASSWORD'] = dbConfig['passwd']
app.config['MYSQL_DB'] = dbConfig['database']
app.config['MYSQL_CURSORCLASS'] = 'DictCursor'
db = MySQL(app)

from geruecht import routes
from geruecht.baruser.routes import baruser
from geruecht.finanzer.routes import finanzer
from geruecht.user.routes import user
from geruecht.vorstand.routes import vorstand

LOGGER.info("Registrate bluebrints")
app.register_blueprint(baruser)
app.register_blueprint(finanzer)
app.register_blueprint(user)
app.register_blueprint(vorstand)
